A list of model coefficients corresponding to the best model that contains at most or at least target_b_gxe_non_zero non-zero interaction terms.
The target model is selected based on the averaged cross-validation (cv) results: for each pair of parameters lambda=(lambda_1, lambda_2) in the grid and each cv fold we obtain a number of non-zero estimated interaction terms, then average cv results by lambda and choose the tuning parameters corresponding to the minimum average cv loss that have at most or at least target_b_gxe_non_zero non-zero interaction terms. Returned coefficients are obtained by fitting the model on the full data with the selected tuning parameters.
Note that the number of estimated non-zero interactions will only approximately reflect the numbers obtained on cv datasets.
beta_0 estimated intercept value
beta_eestimated environmental coefficient value
beta_ga vector of estimated main effect coefficients
beta_gxea vector of estimated interaction coefficients
beta_ca vector of estimated confounders coefficients